# Mancho: A musical transcription assistant.

This is a tool to make musical transcriptions.
Documentation is WIP.

## Installation

Mancho depends on [rubberband](https://breakfastquay.com/rubberband/) and PyGtk3. Make sure these dependencies are installed.

Afterwards:
```bash
python3 setup.py install
```

## Quickstart
Start mancho by running:
```bash
python3 -m mancho
```

1. Load a `.wav` file using the open dialog.
2. You can scroll and zoom using the arrow keys.
3. You can select a region to loop using the mouse.
4. Set the playback using the slider and click play (or press spacebar)
